Phillips1958

Struct Phillips1958 

pub struct Phillips1958 {
    pub alpha: f64,
    pub omega: Array1<f64>,
}
The Phillips high-frequency tail

The Phillips spectrum is an early generational wave spectrum that principally captures the energy distribution in the high-frequency spectral tail. Its canonical form1 is:

$$ S(\omega) = \frac{\alpha g^2}{\omega^5} $$

where $\alpha=0.0081$ denotes the Phillips constant and $g$ is the acceleration due to gravity.

Fields

  • alpha - the Phillips constant (default: 0.0081)
  • omega - frequency range [rad/s]

Methods

  • energy - calculate the energy density spectrum
  • f_hz - return the frequency space in [Hz]
  • to_spec1d - convert to a Spectrum1 type
  • to_spec2d - convert to a Spectrum2 type for a given Spreading type

References


  1. O. M. Phillips, The equilibrium range in the spectrum of wind-generated waves, Journal of Fluid Mechanics, vol. 4, no. 4, pp. 426 434, 1958, doi: 10.1017/S0022112058000550. 

Fields

alpha: f64omega: Array1<f64>

Implementations

Source

impl Phillips1958

pub fn new() -> Self

create a new Phillips spectrum