pub struct Phillips1958 {
pub alpha: f64,
pub omega: Array1<f64>,
}Expand description
The Phillips high-frequency tail
The Phillips spectrum is an early generational wave spectrum that principally captures the energy distribution in the high-frequency spectral tail. Its canonical form1 is:
$$ S(\omega) = \frac{\alpha g^2}{\omega^5} $$
where $\alpha=0.0081$ denotes the Phillips constant and $g$ is the acceleration due to gravity.
Fields
alpha- the Phillips constant (default: 0.0081)omega- frequency range [rad/s]
Methods
energy- calculate the energy density spectrumf_hz- return the frequency space in [Hz]to_spec1d- convert to aSpectrum1typeto_spec2d- convert to aSpectrum2type for a givenSpreadingtype
References
O. M. Phillips, The equilibrium range in the spectrum of wind-generated waves, Journal of Fluid Mechanics, vol. 4, no. 4, pp. 426 434, 1958, doi: 10.1017/S0022112058000550. ↩
Fields
alpha: f64omega: Array1<f64>Implementations
Sourceimpl Phillips1958
impl Phillips1958